@@ -40,7 +40,7 @@ od_radiation <- function(p, pop_var = "population", proportion = 1) {
       sel_flow <- which(l$O == p@data[i, 1] & l$D == p@data[j, 1])
       # create circle the radius of which is the distance between i and j centered on i
       radius <- gprojected(shp = l[sel_flow, ], fun = rgeos::gLength)
-      s_circle <- buff_geo(shp = p[i, ], width = radius)
+      s_circle <- geo_buffer(shp = p[i, ], width = radius)
       ps <- p[-c(i, j), ][s_circle, ]
       s <- sum(ps[[pop_var]])
       l$flow[sel_flow] <-
